@@ -43,7 +43,7 @@ def unicodevalues_asstring(values):
     """ Return string with unicodenames (unless that is disabled) """
     if not os.environ.get('DISABLE_UNAMES'):
         return map(lambda x: '%s' % format(x).strip(), values)
-    return map(lambda x: u'U+%04x %s' % (x, unichr(x)), values)
+    return map(lambda x: u'U+%04x %s' % (x, unichr(x)), sorted(values))
 
 
 extract_firstline = lambda text: \
@@ -52,9 +52,10 @@ extract_firstline = lambda text: \
 
 class Director(object):
 
-    def __init__(self, generate_coverage=None, charmaps=[]):
+    def __init__(self, generate_coverage=None, charmaps=[], missing=False):
         self.generate_coverage = generate_coverage
-        self.charmaps = charmaps
+        self.charmaps = filter(lambda x: x != '', charmaps)
+        self.missingValues = missing
 
     def represent_coverage_png(self, font):
         cmaps = filter(lambda x: hasattr(x, 'key'), library.charmaps)
@@ -66,9 +67,9 @@ class Director(object):
             if self.charmaps:
                 cn = getattr(cmap, 'common_name', False)
                 nn = getattr(cmap, 'native_name', False)
-                if cn and cn not in self._charmaps:
+                if cn and cn not in self.charmaps:
                     continue
-                if nn and nn not in self._charmaps:
+                if nn and nn not in self.charmaps:
                     continue
 
             if cmap.key not in font._unicodeValues:
@@ -97,7 +98,11 @@ class Director(object):
             os.system(hilbertScript)
 
     def construct_tree(self, fonts):
-
+        if self.generate_coverage:
+            try:
+                import matplotlib
+            except ImportError:
+                raise Exception('Install matplotlib to use --coverage feature')
         tree = OrderedDict({'fonts': []})
 
         for font_filename in fonts:
@@ -136,7 +141,8 @@ class Director(object):
                 if support_level != SUPPORT_LEVEL_FULL:
                     values = u'\n%s' % u'\n'.join(unicodevalues_asstring(missing))
                     orth['orthography']['percentCoverage'] = coverage
-                    orth['orthography']['missingValues'] = values
+                    if self.missingValues:
+                        orth['orthography']['missingValues'] = values
 
                 desc['orthographies'].append(orth)
 
@@ -184,6 +190,27 @@ class Builder(object):
         data.seek(0)
         return data.read()
 
+    @staticmethod
+    def wiki(fonts):
+        for font_filename in fonts:
+            font = Font(font_filename)
+            print('=== %s ===' % font.common_name.encode('ascii', 'ignore'))
+            print('{|')
+            print('| colspan=3 |')
+            for subset in library.charmaps:
+                charmap, supported, coverage, missing = font.get_othography_info(subset)
+                if supported == SUPPORT_LEVEL_UNSUPPORTED:
+                    continue
+
+                glyphs = charmap.glyphs
+                if callable(glyphs):
+                    glyphs = glyphs()
+
+                print('|-')
+                print("| [[ %s ]] (%s/%s)  || style='text-align:right'" % (charmap.common_name, len(glyphs) - len(missing), len(glyphs)),
+                      " | {{bartable|%s|%%|2||background:green}}" % coverage)
+            print('|}')
+
 
 NAMES = {
     'fonts': 'Fonts',
