@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
-from fontaine.cmap import library
-
 class Charmap:
-    common_name = u'GWF extras'
+    common_name = u'Google extras'
     native_name = u''
 
     def glyphs(self):
@@ -11,4 +9,4 @@ class Charmap:
         glyphs += [0xf000] # PUA: font ppem size indicator: run `ftview -f 1255 10 Ubuntu-Regular.ttf` to see it in action!
         return glyphs
 
-library.register(Charmap)
+
